Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJulien Moumné <julien@piwik.org>2013-05-19 12:18:32 +0400
committerJulien Moumné <julien@piwik.org>2013-05-19 12:18:32 +0400
commit8a8ce3eccb13c11037b79112513bcbe6ef7e2ccf (patch)
tree83792550c0d26696acd9a48a2780fc435b822842 /core/ReportRenderer.php
parent1ec86574db8537a1290043820455205e9863ad64 (diff)
ref #71, #3934 - segment selection for scheduled html, pdf & sms reports
Diffstat (limited to 'core/ReportRenderer.php')
-rw-r--r--core/ReportRenderer.php18
1 files changed, 10 insertions, 8 deletions
diff --git a/core/ReportRenderer.php b/core/ReportRenderer.php
index 0c0bc73243..131830a996 100644
--- a/core/ReportRenderer.php
+++ b/core/ReportRenderer.php
@@ -103,9 +103,10 @@ abstract class Piwik_ReportRenderer
* @param string $reportTitle
* @param string $prettyDate formatted date
* @param string $description
* @param array $reportMetadata metadata for all reports
*/
- abstract public function renderFrontPage($reportTitle, $prettyDate, $description, $reportMetadata);
+ abstract public function renderFrontPage($reportTitle, $prettyDate, $description, $reportMetadata, $segment);
/**
* Render the provided report.
@@ -215,7 +216,7 @@ abstract class Piwik_ReportRenderer
);
}
- public static function getStaticGraph($reportMetadata, $width, $height, $evolution)
+ public static function getStaticGraph($reportMetadata, $width, $height, $evolution, $segment)
{
$imageGraphUrl = $reportMetadata['imageGraphUrl'];
@@ -226,11 +227,12 @@ abstract class Piwik_ReportRenderer
$request = new Piwik_API_Request(
$imageGraphUrl .
- '&outputType=' . Piwik_ImageGraph_API::GRAPH_OUTPUT_PHP .
- '&format=original&serialize=0' .
- '&filter_truncate=' .
- '&width=' . $width .
- '&height=' . $height
+ '&outputType=' . Piwik_ImageGraph_API::GRAPH_OUTPUT_PHP .
+ '&format=original&serialize=0' .
+ '&filter_truncate=' .
+ '&width=' . $width .
+ '&height=' . $height .
+ ($segment != null ? '&segment=' . $segment['definition'] : '')
);
try {
@@ -103,9 +103,10 @@ abstract class Piwik_ReportRenderer
* @param string $prettyDate formatted date
* @param string $description
- * @param array $reportMetadata metadata for all reports
+ * @param array $reportMetadata metadata for all reports
+ * @param array $segment segment applied to all reports
*/